nvector._core.intersect — nvector 0.7.5 documentation

# nvector._core.intersect

`intersect`(path_a, path_b)

  Returns the intersection(s) between the great circles of the two paths

  Parameters
    path_a, path_b: tuple of 2 n-vectors

      defining path A and path B, respectively. Path A and B has shape 2 x 3 x n and 2 x 3 x m, respectively.

  Returns
    n_EC_Earray of shape 3 x max(n, m)

      n-vector(s) [no unit] of position C decomposed in E. point(s) of intersection between paths.